require'iuplua'

HangarDialog = {}

local version_str = ""

HangarDialog.open = function(ships, data)
  version_str = data.version
  HangarDialog.instance = HangarDialog:new(ships)
  HangarDialog.instance:show()
end

function HangarDialog:new (ships)
  local hangar_dialog = {}

  hangar_dialog.main_box = iup.vbox{gap=25}
  hangar_dialog.dlg = iup.dialog{
    hangar_dialog.main_box,
    title="Ships",
    expand="YES",
    active="YES",
    bgcolor="0 0 0 128 *",
    fullscreen="YES",
    topmost = "YES",
    BORDER="NO",
    RESIZE="NO",
    MAXBOX="NO",
    MINBOX="NO",
    MENUBOX="NO",
    MODAL="YES"
  }
  function hangar_dialog.dlg:close_cb()
    self:hide()
  end

  local first_row = iup.hbox{size="x%40",gap="%2"}
  local second_row = iup.hbox{size="x%40",gap="%2"}

  for i,ship in ipairs(ships) do
    local btn = iup.button{ship_id=ship.id,
                           title="Launch",
                           size="%32x35",
                           bgcolor="32 128 32 192 *"
                         }
    function btn:action ()
      RequestLaunch(ship.id) -- simple, isn't it :)
    end

    local addons_list = iup.list {"<no addons>", size="%32x%6"}
    for i,item_id in ipairs(ship.addons) do
      addons_list[i] = GetInventoryItemName(item_id)
    end
    local cargo_list = iup.list {"<no cargo>", size="%32x%15"}
    for i,item_id in ipairs(ship.cargo) do
      cargo_list[i] = GetInventoryItemQuantity(item_id).."x "..GetInventoryItemName(item_id)
    end

    local cell = iup.vbox{
      iup.label{title=ship.name,font="24"},
      iup.fill{size=15},
      iup.label{title="Addons: ("..#ship.addons..")"},
      addons_list,
      iup.fill{size=15},
      iup.label{title="Cargo ("..ship.capacity_str..")"},
      cargo_list,
      btn,
      size="%32x%40"
    }

    if i <= 3 then
      iup.Append(first_row, cell)
    else
      iup.Append(second_row, cell)
    end
  end

  local close_btn = iup.button{title="Close", expand="YES", bgcolor="64 0 0 192 *"}
  function close_btn:action ()
    hangar_dialog:hide()
  end

  iup.Append(hangar_dialog.main_box, iup.hbox{
    iup.fill{}, 
    iup.label{title="Hangar "..version_str},
  })
  iup.Append(hangar_dialog.main_box, first_row)
  iup.Append(hangar_dialog.main_box, second_row)
  iup.Append(hangar_dialog.main_box, iup.hbox{
    expand="YES",
    close_btn           
  })

  function hangar_dialog:show()
    self.dlg:show()
    self.dlg.active = "YES"
  end

  function hangar_dialog:hide()
    self.dlg:hide()
    self.dlg.active = "no"
    iup.Destroy(self.dlg)
    self.dlg = nil
  end

  return hangar_dialog
end

function HangarDialog:OnEvent(event, data)
  if HangarDialog.instance ~= nil and HangarDialog.instance.dlg ~= nil then
    HangarDialog.instance:hide()
    HangarDialog.instance = nil
  end
end
RegisterEvent(HangarDialog, "HUD_SHOW")
RegisterEvent(HangarDialog, "HUD_HIDE")
RegisterEvent(HangarDialog, "SECTOR_CHANGED")
RegisterEvent(HangarDialog, "SHOW_STATION")
